==> peoplesoft_selenium_components-0.1.2.tar.gz: peoplesoft_selenium_components-0.1.2/README.md <==
# PeopleSoft Components Library

A Python library designed to simplify finding and interacting with PeopleSoft components using Selenium WebDriver. This library provides abstractions for commonly used UI elements in PeopleSoft applications, such as buttons, tiles, and input fields.

## Features

- **Modular Components**: Includes Button, Image, TextInput, PasswordInput, and Tile components, each designed to make interaction with PeopleSoft UI elements straightforward.
- **Robust Base Classes**: Provides `BaseComponent` and `BaseInput` classes for building custom components.
- **Selenium Integration**: Fully compatible with Selenium WebDriver.

---

## Installation

Install the package directly from the GitLab Package Registry:

```bash
pip install --index-url https://gitlab.com/api/v4/projects/64588891/packages/pypi peoplesoft-components
```

---

## Usage

### General Usage

Import the components and use them to interact with PeopleSoft UI elements in your Selenium scripts:

```python
from selenium import webdriver
from peoplesoft_components import Button, TextInput, Tile


driver = webdriver.Chrome()
driver.get("https://your-peoplesoft-url.com")

# Interact with a button
button = Button.get_by_label(driver, "Submit")
button.click()

# Fill a text input field
text_input = TextInput.get_by_label(driver, "Username")
text_input.send_keys("my_username")

# Interact with a tile
tile = Tile.get_by_label(driver, "Student Center")
tile.click()
```

---

### Components

This library provides several pre-defined components for interacting with PeopleSoft UI elements.  
Below are details for each component, including how to find and interact with them.  
**N.B. All components extend a normal Selenium WebElement, meaning you have access to all the native Selenium methods and interactions.**

#### Button

Represents a button element (`<input>` with the class `ps-button`).

- **Methods**:
  - `Button.get_by_label(driver, label)`: Finds a button by its label (the `value` attribute of the `<input>`).

Example:

```python
from peoplesoft_components import Button


button = Button.get_by_label(driver, "Submit") 
button.click()
```

---

#### TextInput

Represents a text input element (`<input>` with type `text`).

- **Methods**:
  - `TextInput.get_by_label(driver, label)`: Finds a text input field by its associated `<label>` text.

Example:

```python
from peoplesoft_components import TextInput


text_input = TextInput.get_by_label(driver, "Username")
text_input.send_keys("my_username")
```

---

#### PasswordInput

Represents a password input element (`<input>` with type `password`).

- **Methods**:
  - `PasswordInput.get_by_label(driver, label)`: Finds a password input field by its associated `<label>` text.

Example:

```python
from peoplesoft_components import PasswordInput


password_input = PasswordInput.get_by_label(driver, "Password")
password_input.send_keys("my_password")
```

---

#### Tile

Represents a tile element, typically found in dashboards or navigation areas.

- **Methods**:
  - `Tile.get_by_label(driver, label)`: Finds a tile by its visible label text.

Example:

```python
from peoplesoft_components import Tile


tile = Tile.get_by_label(driver, "Student Center")
tile.click()
```

---

#### Image

Represents an image element (`<img>`).

- **Methods**:
  - `Image.get_by_alt_text(driver, alt_text)`: Finds an image by its `alt` attribute.

Example:

```python
from peoplesoft_components import Image


image = Image.get_by_alt_text(driver, "Logo") 
src = image.get_attribute("src") 
```

---

## Getting Started with Development

To set up the project for development:

### 1. Clone the Repository

```bash
git clone https://gitlab.com/campus-solutions-automated-testing-group/peoplesoft-selenium-components.git  
cd peoplesoft-selenium-components
````

### 2. Install Dependencies

Use a virtual environment and install the required dependencies:

```bash
python -m venv venv  
source venv/bin/activate  # On Windows: venv\Scripts\activate  
pip install -r requirements.txt
```

### 3. Build the Package

Build the package locally to test distribution:

```bash
python -m build
```

---

## Resources

- **Homepage**: [Project Homepage](https://gitlab.com/campus-solutions-automated-testing-group/peoplesoft-selenium-components)
- **Selenium Documentation**: [Selenium](https://www.selenium.dev/documentation/)

---

## Contributing

Contributions are welcome! Please fork the repository, create a feature branch, and submit a merge request. Ensure all new code is covered by tests.

---

## License

This project is licensed under the terms specified in the `LICENSE` file.

==> peoplesoft_selenium_components-0.2.0.tar.gz: peoplesoft_selenium_components-0.2.0/README.md <==
# PeopleSoft Components Library

A Python library designed to simplify finding and interacting with PeopleSoft components using Selenium WebDriver. This library provides abstractions for commonly used UI elements in PeopleSoft applications, such as buttons, tiles, and input fields.

## Features

- **Modular Components**: Includes Button, Image, TextInput, PasswordInput, and Tile components, each designed to make interaction with PeopleSoft UI elements straightforward.
- **Robust Base Classes**: Provides `BaseComponent` and `BaseInput` classes for building custom components.
- **Selenium Integration**: Fully compatible with Selenium WebDriver.

---

## Installation

Install the package directly from the GitLab Package Registry:

```bash
pip install --index-url https://gitlab.com/api/v4/projects/64588891/packages/pypi peoplesoft-components
```

---

## Usage

### General Usage

Import the components and use them to interact with PeopleSoft UI elements in your Selenium scripts:

```python
from selenium import webdriver
from peoplesoft_components import Button, TextInput, Tile


driver = webdriver.Chrome()
driver.get("https://your-peoplesoft-url.com")

# Interact with a button
button = Button.find(driver, "Submit")
button.click()

# Fill a text input field
text_input = TextInput.find(driver, "Username")
text_input.set_value("my_username")

# Interact with a tile
tile = Tile.find(driver, "Student Center")
tile.click()
```

---

### Components

This library provides several pre-defined components for interacting with PeopleSoft UI elements.  
Below are details for each component, including how to find and interact with them.  
**N.B. All components extend a normal Selenium WebElement, meaning you have access to all the native Selenium methods and interactions.**

#### Button

Represents a button element (`<input>` with the class `ps-button`).

- **Methods**:
  - `Button.find(driver, label)`: Finds a button by its label (the `value` attribute of the `<input>`).

Example:

```python
from peoplesoft_components import Button


button = Button.find(driver, "Submit") 
button.click()
```

---

#### TextInput

Represents a text input element (`<input>` with type `text`).

- **Methods**:
  - `TextInput.find(driver, label)`: Finds a text input field by its associated `<label>` text.

Example:

```python
from peoplesoft_components import TextInput


text_input = TextInput.find(driver, "Username")
text_input.set_value("my_username")
```

---

#### PasswordInput

Represents a password input element (`<input>` with type `password`).

- **Methods**:
  - `PasswordInput.find(driver, label)`: Finds a password input field by its associated `<label>` text.

Example:

```python
from peoplesoft_components import PasswordInput


password_input = PasswordInput.find(driver, "Password")
password_input.set_value("my_password")
```

---

#### Tile

Represents a tile element, typically found in dashboards or navigation areas.

- **Methods**:
  - `Tile.find(driver, label)`: Finds a tile by its visible label text.

Example:

```python
from peoplesoft_components import Tile


tile = Tile.find(driver, "Student Center")
tile.click()
```

---

#### Image

Represents an image element (`<img>`).

- **Methods**:
  - `Image.find(driver, alt_text)`: Finds an image by its `alt` attribute.

Example:

```python
from peoplesoft_components import Image


image = Image.find(driver, "Logo") 
assert image.is_displayed()
```

---

## Getting Started with Development

To set up the project for development:

### 1. Clone the Repository

```bash
git clone https://gitlab.com/campus-solutions-automated-testing-group/peoplesoft-selenium-components.git  
cd peoplesoft-selenium-components
````

### 2. Install Dependencies

Use a virtual environment and install the required dependencies:

```bash
python -m venv venv  
source venv/bin/activate  # On Windows: venv\Scripts\activate  
pip install -r requirements.txt
```

### 3. Build the Package

Build the package locally to test distribution:

```bash
python -m build
```

---

## Resources

- **Homepage**: [Project Homepage](https://gitlab.com/campus-solutions-automated-testing-group/peoplesoft-selenium-components)
- **Selenium Documentation**: [Selenium](https://www.selenium.dev/documentation/)

---

## Contributing

Contributions are welcome! Please fork the repository, create a feature branch, and submit a merge request.

---

## License

This project is licensed under the terms specified in the `LICENSE` file.
